summaryrefslogtreecommitdiffstats
path: root/native/src/window
diff options
context:
space:
mode:
Diffstat (limited to 'native/src/window')
-rw-r--r--native/src/window/action.rs34
1 files changed, 17 insertions, 17 deletions
diff --git a/native/src/window/action.rs b/native/src/window/action.rs
index 929663ec..63858bc8 100644
--- a/native/src/window/action.rs
+++ b/native/src/window/action.rs
@@ -1,4 +1,4 @@
-use crate::window;
+use crate::window::{Mode, UserAttention};
use iced_futures::MaybeSend;
use std::fmt;
@@ -38,20 +38,21 @@ pub enum Action<T> {
/// The new logical y location of the window
y: i32,
},
- /// Set the [`Mode`] of the window.
- SetMode(window::Mode),
+ /// Change the [`Mode`] of the window.
+ ChangeMode(Mode),
/// Fetch the current [`Mode`] of the window.
- FetchMode(Box<dyn FnOnce(window::Mode) -> T + 'static>),
- /// Sets the window to maximized or back
+ FetchMode(Box<dyn FnOnce(Mode) -> T + 'static>),
+ /// Toggle the window to maximized or back
ToggleMaximize,
- /// Toggles whether window has decorations
+ /// Toggle whether window has decorations.
+ ///
/// ## Platform-specific
/// - **X11:** Not implemented.
/// - **Web:** Unsupported.
ToggleDecorations,
- /// Requests user attention to the window, this has no effect if the application
+ /// Request user attention to the window, this has no effect if the application
/// is already focused. How requesting for user attention manifests is platform dependent,
- /// see [`UserAttentionType`] for details.
+ /// see [`UserAttention`] for details.
///
/// Providing `None` will unset the request for user attention. Unsetting the request for
/// user attention might not be done automatically by the WM when the window receives input.
@@ -62,8 +63,8 @@ pub enum Action<T> {
/// - **macOS:** `None` has no effect.
/// - **X11:** Requests for user attention must be manually cleared.
/// - **Wayland:** Requires `xdg_activation_v1` protocol, `None` has no effect.
- RequestUserAttention(Option<window::UserAttention>),
- /// Brings the window to the front and sets input focus. Has no effect if the window is
+ RequestUserAttention(Option<UserAttention>),
+ /// Bring the window to the front and sets input focus. Has no effect if the window is
/// already in focus, minimized, or not visible.
///
/// This method steals input focus from other applications. Do not use this method unless
@@ -93,7 +94,7 @@ impl<T> Action<T> {
Self::Maximize(bool) => Action::Maximize(bool),
Self::Minimize(bool) => Action::Minimize(bool),
Self::Move { x, y } => Action::Move { x, y },
- Self::SetMode(mode) => Action::SetMode(mode),
+ Self::ChangeMode(mode) => Action::ChangeMode(mode),
Self::FetchMode(o) => Action::FetchMode(Box::new(move |s| f(o(s)))),
Self::ToggleMaximize => Action::ToggleMaximize,
Self::ToggleDecorations => Action::ToggleDecorations,
@@ -115,15 +116,14 @@ impl<T> fmt::Debug for Action<T> {
}
Self::Resize { width, height } => write!(
f,
- "Action::Resize {{ widget: {}, height: {} }}",
- width, height
+ "Action::Resize {{ widget: {width}, height: {height} }}"
),
- Self::Maximize(value) => write!(f, "Action::Maximize({})", value),
- Self::Minimize(value) => write!(f, "Action::Minimize({}", value),
+ Self::Maximize(value) => write!(f, "Action::Maximize({value})"),
+ Self::Minimize(value) => write!(f, "Action::Minimize({value}"),
Self::Move { x, y } => {
- write!(f, "Action::Move {{ x: {}, y: {} }}", x, y)
+ write!(f, "Action::Move {{ x: {x}, y: {y} }}")
}
- Self::SetMode(mode) => write!(f, "Action::SetMode({:?})", mode),
+ Self::ChangeMode(mode) => write!(f, "Action::SetMode({mode:?})"),
Self::FetchMode(_) => write!(f, "Action::FetchMode"),
Self::ToggleMaximize => write!(f, "Action::ToggleMaximize"),
Self::ToggleDecorations => write!(f, "Action::ToggleDecorations"),